// //////////////////////////////////////////////////////////////////////////
// Implementation file CppLineParser.cpp for class CppLineParser
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////

#include <qstring.h>
#include "CppLineParser.h"
#include "CppLineParserBuilder.h"


CppLineParser::CppLineParser( const QString &line,
                              CppLineParserBuilder *builder ) :
    _line( line.stripWhiteSpace() )
{
  static const QString include = QString::fromLatin1( "include" );

  if ( isPreprocessorDirective() )
  {
    int index = skipSpacesStartingAt( 1 );
    if ( include == _line.mid( index, include.length() ) )
    {
      index = skipSpacesStartingAt( index + include.length() );
      parseIncludeArg( index, builder );
    }
  }
}


CppLineParser::~CppLineParser()
{
}


void 
CppLineParser::parseIncludeArg( int index,
                                CppLineParserBuilder *builder )
{
  ++index;    // skip < or "

  int indexEndFileName = _line.find( '"', index );
  bool searchParentDir = true;
  if ( indexEndFileName < 0 )
  {
    indexEndFileName = _line.find( '>', index );
    searchParentDir = false;
  }

  if ( indexEndFileName >= 0 )
  {
    builder->fileIncluded( _line.mid( index, indexEndFileName -index ), 
                           searchParentDir );
  }
}


int 
CppLineParser::skipSpacesStartingAt( int index )
{
  while ( _line.at( index ).isSpace() )
    ++index;
  return index;
}


bool 
CppLineParser::isPreprocessorDirective()
{
  return _line.at(0) == '#';
}
