// //////////////////////////////////////////////////////////////////////////
// Implementation file CppLineParserTest.cpp for class CppLineParserTest
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////

#include "CppLineParserTest.h"
#include "CppLineParser.h"
#include "QtCppUnitTools.h"


CPPUNIT_TEST_SUITE_REGISTRATION( CppLineParserTest );


CppLineParserTest::CppLineParserTest() : 
    CppUnit::TestCase()
{
}


CppLineParserTest::~CppLineParserTest()
{
  _dependencies.setAutoDelete( TRUE );
}


void 
CppLineParserTest::setUp()
{
  _expectedIndex = 0;
}


void 
CppLineParserTest::tearDown()
{
  _dependencies.clear();
}


void 
CppLineParserTest::testEmptyLine()
{
  CppLineParser parser( "", this );
  expectNoMore();
}


void 
CppLineParserTest::testQuotedTestHeader()
{
  CppLineParser parser( "#include \"TestHeader.h\"", this );
  expect( "TestHeader.h", true );
  expectNoMore();
}


void 
CppLineParserTest::testQuotedTestHeader2()
{
  CppLineParser parser( "#include \"TestHeader2.h\"", this );
  expect( "TestHeader2.h", true );
  expectNoMore();
}


void 
CppLineParserTest::testAngledTinyHeader()
{
  CppLineParser parser( "#include <a>", this );
  expect( "a", false );
  expectNoMore();
}


void 
CppLineParserTest::testIndentedHeaderWithTrailingSpaces()
{
  CppLineParser parser( " \t  #include <MyHeader.h>\t ", this );
  expect( "MyHeader.h", false );
  expectNoMore();
}


void 
CppLineParserTest::testSharpSpacesIncludeHeader()
{
  CppLineParser parser( "#\t include <MyHeader.>", this );
  expect( "MyHeader.", false );
  expectNoMore();
}


void 
CppLineParserTest::testEmptyInclude()
{
  CppLineParser parser( "#include <>", this );
  expect( "", false );
  expectNoMore();
}


void 
CppLineParserTest::testCollatedInclude()
{
  CppLineParser parser( "#include<a>", this );
  expect( "a", false );
  expectNoMore();
}


void 
CppLineParserTest::testIncludeWithPath()
{
  CppLineParser parser( "#include <cppunit/extensions/HelperMacros.h>", this );
  expect( "cppunit/extensions/HelperMacros.h", false );
  expectNoMore();
}


void 
CppLineParserTest::testIncludeWithTrailingComment()
{
  CppLineParser parser( "#include <MyHeader.h> // include comment", this );
  expect( "MyHeader.h", false );
  expectNoMore();
}


void 
CppLineParserTest::testCommentWithIncludeDirectiveWithin()
{
  CppLineParser parser( "// #include <MyHeader.h>", this );
  expectNoMore();
}


void 
CppLineParserTest::expectNoMore()
{
  CPPUNIT_ASSERT_EQUAL( _expectedIndex, int(_dependencies.count()) );
}


void 
CppLineParserTest::expect( const QString &fileName,
                           bool searchParentDir )
{
  CPPUNIT_ASSERT( _expectedIndex < _dependencies.count() );
  
  FileIncluded *include = _dependencies.at( _expectedIndex );
  CPPUNIT_ASSERT_EQUAL( fileName, include->_fileName );
  CPPUNIT_ASSERT_EQUAL( searchParentDir, include->_searchParentDir );

  ++_expectedIndex;
}


void 
CppLineParserTest::fileIncluded( const QString &fileName,
                                 bool searchParentDir )
{
  _dependencies.append( new FileIncluded( fileName, searchParentDir ) );
}
