// //////////////////////////////////////////////////////////////////////////
// Header file CppLineParserTest.h for class CppLineParserTest
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////
#ifndef CPPLINEPARSERTEST_H
#define CPPLINEPARSERTEST_H

#include <cppunit/extensions/HelperMacros.h>
#include <qlist.h>
#include <qstring.h>
#include "CppLineParserBuilder.h"


/*! \class CppLineParserTest
 * \brief Unit test for CppLineParser.
 */
class CppLineParserTest : public CppUnit::TestCase,
                          private CppLineParserBuilder
{
  CPPUNIT_TEST_SUITE( CppLineParserTest );
  CPPUNIT_TEST( testEmptyLine );
  CPPUNIT_TEST( testQuotedTestHeader );
  CPPUNIT_TEST( testQuotedTestHeader2 );
  CPPUNIT_TEST( testAngledTinyHeader );
  CPPUNIT_TEST( testIndentedHeaderWithTrailingSpaces );
  CPPUNIT_TEST( testSharpSpacesIncludeHeader );
  CPPUNIT_TEST( testEmptyInclude );
  CPPUNIT_TEST( testCollatedInclude );
  CPPUNIT_TEST( testIncludeWithPath );
  CPPUNIT_TEST( testIncludeWithTrailingComment );
  CPPUNIT_TEST( testCommentWithIncludeDirectiveWithin );
  CPPUNIT_TEST_SUITE_END();

public:
  /*! Constructs a CppLineParserTest object.
   */
  CppLineParserTest();

  /// Destructor.
  virtual ~CppLineParserTest();

  void setUp();
  void tearDown();

  void testEmptyLine();
  void testQuotedTestHeader();
  void testQuotedTestHeader2();
  void testAngledTinyHeader();
  void testIndentedHeaderWithTrailingSpaces();
  void testSharpSpacesIncludeHeader();
  void testEmptyInclude();
  void testCollatedInclude();
  void testIncludeWithPath();
  void testIncludeWithTrailingComment();
  void testCommentWithIncludeDirectiveWithin();

private:
  struct FileIncluded
  {
    FileIncluded( QString fileName, bool searchParentDir ) :
        _fileName( fileName ),
        _searchParentDir( searchParentDir )
    {
    }
    QString _fileName;
    bool _searchParentDir;
  };

  /// Prevents the use of the copy constructor.
  CppLineParserTest( const CppLineParserTest &copy );

  /// Prevents the use of the copy operator.
  void operator =( const CppLineParserTest &copy );

  void expectNoMore();
  
  void expect( const QString &fileName,
               bool searchParentDir );
  
  void fileIncluded( const QString &fileName,
                     bool searchParentDir );

private:
  QList<FileIncluded> _dependencies;
  int _expectedIndex;
};



// Inlines methods for CppLineParserTest:
// --------------------------------------



#endif  // CPPLINEPARSERTEST_H
