// //////////////////////////////////////////////////////////////////////////
// Implementation file ExpectedFile.cpp for class ExpectedFile
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////

#include "ExpectedFile.h"
#include "ExpectedProject.h"
#include "FileModelIterator.h"
#include "ResolvedFileModel.h"


ExpectedFile::ExpectedFile( const QString &relativeFileName ) :
    _project( NULL ),
    _relativeFileName( relativeFileName )
{
}


ExpectedFile::~ExpectedFile()
{
}


QString 
ExpectedFile::fullPathName()
{
  return _project->fullPathNameFor( _relativeFileName );
}


void 
ExpectedFile::addFile( ExpectedFile *file )
{
  _files.append( file );
  file->setProject( _project );
}


ExpectedFile *
ExpectedFile::addFile( const QString &relativeFileName )
{
  ExpectedFile *file = new ExpectedFile( relativeFileName );
  addFile( file );
  return file;
}


void 
ExpectedFile::setProject( ExpectedProject *project )
{
  if ( project == NULL )
    return;

  _project = project;

  QListIterator<ExpectedFile> it( _files );
  for ( ; it.current(); ++it )
    it.current()->setProject( _project );
}


void 
ExpectedFile::checkSameAs( ResolvedFileModel *actualFile,
                           QString *message )
{
  if ( fullPathName() != actualFile->fullPathName() )
  {
    *message += "expected: " + angledPathName() +"\n" +
                "was     : " + actualFile->angledPathName() + "\n";
    return;
  }

  QListIterator<ExpectedFile> itFile( _files );
  FileModelIterator itActualFiles( actualFile->includedFiles() );
  for ( ; itFile.current(); ++itFile )
  {
    ExpectedFile *expectedFile = itFile.current();
    if ( !itActualFiles.hasNextItem() )
    {
      *message += "missing actual for: " + 
                  expectedFile->angledPathName() + "\n";
      break;
    }

    ResolvedFileModel *actualFile = itActualFiles.nextItem();
    expectedFile->checkSameAs( actualFile, message );
    if ( !message->isNull() )
      break;
  }

  if ( itActualFiles.hasNextItem()  &&  message->isNull() )
  {
    ResolvedFileModel *actualFile = itActualFiles.nextItem();
    *message += "missing expected for: " + 
                actualFile->angledPathName() + "\n";
  }

  if ( !message->isNull() )
    *message += "-> included from: " + angledPathName() + "\n";
}


QString 
ExpectedFile::angledPathName()
{
  return "<" + fullPathName() + ">";
}
