// //////////////////////////////////////////////////////////////////////////
// Implementation file ExpectedProject.cpp for class ExpectedProject
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////

#include <qfileinfo.h>
#include <cppunit/TestAssert.h>
#include "ExpectedFile.h"
#include "ExpectedProject.h"
#include "FileModelIterator.h"
#include "ProjectModel.h"
#include "QtCppUnitTools.h"
#include "ResolvedFileModel.h"


ExpectedProject::ExpectedProject( const QString &projectDirectory ) :
    _projectDirectory( projectDirectory ),
    _files( new QList<ExpectedFile>() )
{
  _files->setAutoDelete( TRUE );
}


ExpectedProject::~ExpectedProject()
{
  delete _files;
}


QString 
ExpectedProject::fullPathNameFor( const QString &relativeFileName )
{
  QFileInfo file( _projectDirectory + relativeFileName );
  return file.absFilePath();
}


void 
ExpectedProject::addFile( ExpectedFile *file )
{
  file->setProject( this );
  _files->append( file );
}


void 
ExpectedProject::checkSameAs( ProjectModel *project )
{
  QString message = QString::null;

  CPPUNIT_ASSERT_EQUAL( fullPathNameFor("") + "/",
                        project->absoluteProjectPath() );
  
  QListIterator<ExpectedFile> itFile( *_files );
  FileModelIterator itActualFiles( project->files() );
  for ( ; itFile.current(); ++itFile )
  {
    ExpectedFile *expectedFile = itFile.current();
    if ( !itActualFiles.hasNextItem() )
    {
      message += "missing actual for: " + 
                 expectedFile->angledPathName() + "\n";
      break;
    }

    ResolvedFileModel *actualFile = itActualFiles.nextItem();
    expectedFile->checkSameAs( actualFile, &message );
    if ( !message.isNull() )
      break;
  }

  if ( itActualFiles.hasNextItem()  &&  message.isNull() )
  {
    ResolvedFileModel *actualFile = itActualFiles.nextItem();
    message += "missing expected for: " + 
               actualFile->angledPathName() + "\n";
  }

  if ( !message.isNull() )
    CPPUNIT_ASSERT_MESSAGE( message.latin1(), false );
}
