// //////////////////////////////////////////////////////////////////////////
// Implementation file ExpectedProjectTest.cpp for class ExpectedProjectTest
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/24
// //////////////////////////////////////////////////////////////////////////

#include "ExpectedProjectTest.h"
#include "ExpectedFile.h"
#include "ExpectedProject.h"
#include "FileModelIterator.h"
#include "ProjectModel.h"
#include "ProjectModelTest.h"
#include "QtCppUnitTools.h"
#include "ResolvedFileModel.h"


CPPUNIT_TEST_SUITE_REGISTRATION( ExpectedProjectTest );


ExpectedProjectTest::ExpectedProjectTest() : 
    CppUnit::TestCase()
{
}


ExpectedProjectTest::~ExpectedProjectTest()
{
}


void 
ExpectedProjectTest::setUp()
{
  _dir = "../Test/Project1/";
}


void 
ExpectedProjectTest::tearDown()
{
}


void 
ExpectedProjectTest::testDifferentProjectPath()
{
  ProjectModel actualProject( _dir );
  ExpectedProject project( _dir + "/Bad/" );
  project.checkSameAs( &actualProject );
}


void 
ExpectedProjectTest::testMissingActualTopFile()
{
  ProjectModel actualProject( _dir );

  ExpectedProject project( _dir );
  project.addFile( new ExpectedFile( "Object.cpp" ) );

  project.checkSameAs( &actualProject );
}


void 
ExpectedProjectTest::testMissingActualTopFile2()
{
  ProjectModel actualProject( _dir );
  actualProject.addFile( "Object.cpp" );

  ExpectedProject project( _dir );
  project.addFile( new ExpectedFile( "Object.cpp" ) );
  project.addFile( new ExpectedFile( "ObjectNoInclude.cpp" ) );

  project.checkSameAs( &actualProject );
}


void 
ExpectedProjectTest::testMissingExpectedTopFile()
{
  ProjectModel actualProject( _dir );
  actualProject.addFile( "Object.cpp" );

  ExpectedProject project( _dir );

  project.checkSameAs( &actualProject );
}


void 
ExpectedProjectTest::testMissingExpectedTopFile2()
{
  ProjectModel actualProject( _dir );
  actualProject.addFile( "Object.cpp" );
  actualProject.addFile( "ObjectNoInclude.cpp" );

  ExpectedProject project( _dir );
  project.addFile( new ExpectedFile( "Object.cpp" ) );

  project.checkSameAs( &actualProject );
}


void 
ExpectedProjectTest::testMissingActualIncludedFile()
{
  ProjectModel actualProject( _dir );
  actualProject.addFile( "ObjectNoInclude.cpp" );

  ExpectedProject project( _dir );
  ExpectedFile *file = new ExpectedFile( "ObjectNoInclude.cpp" );
  project.addFile( file );
  file->addFile( new ExpectedFile( "Object.h" ) );

  project.checkSameAs( &actualProject );
}


void 
ExpectedProjectTest::testMissingExpectedIncludedFile()
{
  ProjectModel actualProject( _dir );
  actualProject.addFile( "Object.cpp" );

  ExpectedProject project( _dir );
  ExpectedFile *file = new ExpectedFile( "Object.cpp" );
  project.addFile( file );

  project.checkSameAs( &actualProject );
}
