// //////////////////////////////////////////////////////////////////////////
// Implementation file FileModel.cpp for class FileModel
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////

#include <qfile.h>
#include <qfileinfo.h>
#include <qtextstream.h>
#include <stdexcept>
#include "FileModel.h"
#include "CppLineParser.h"


FileModel::FileModel( const QString &fullPathName,
                      bool readDependency ) :
    _fullPathName( fullPathName )
{
  _dependencies.setAutoDelete( TRUE );

  if ( readDependency )
    findDependencies();
}


FileModel::~FileModel()
{
}


QVector<FileDependency>
FileModel::dependencies()
{
  QVector<FileDependency> dependencies( _dependencies.count() );
  QListIterator<FileDependency> it( _dependencies );
  for ( int index = 0; it.current(); ++it, ++index )
    dependencies.insert( index, it.current() );

  return dependencies;
}


void 
FileModel::findDependencies()
{
  QFile file( _fullPathName );
  if ( !file.open( IO_ReadOnly ) )
  {
    QString msg = "FileModel::findDependencies(): bad path, ";
    msg += _fullPathName;
    throw std::invalid_argument( msg.latin1() );
  }

  QTextStream stream( &file );
  QString line;
  while ( true )
  {
    line = stream.readLine();
    if ( line.isNull() )
      break;

    CppLineParser parser( line, this );
  }
}


void 
FileModel::fileIncluded( const QString &fileName,
                         bool searchParentDir )
{
  _dependencies.append( new FileDependency( fileName, 
                                            searchParentDir ) );
}


QString 
FileModel::fullPathName()
{
  return _fullPathName;
}


QString 
FileModel::directoryPath()
{
  return QFileInfo(_fullPathName).dirPath(TRUE) + '/';
}
