// //////////////////////////////////////////////////////////////////////////
// Header file FileModel.h for class FileModel
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////
#ifndef FILEMODEL_H
#define FILEMODEL_H

#include <qlist.h>
#include <qvector.h>
#include "CppLineParserBuilder.h"
#include "FileDependency.h"


/*! \class FileModel
 * \brief This class represents a file which may have some dependencies to other files.
 */
class FileModel : private CppLineParserBuilder
{
public:
  /*! Constructs a FileModel object.
   */
  FileModel( const QString &fullPathName,
             bool readDependency = true );

  /// Destructor.
  virtual ~FileModel();

  QString fullPathName();

  QString directoryPath();

  QVector<FileDependency> dependencies();

private:
  /// Prevents the use of the copy constructor.
  FileModel( const FileModel &copy );

  /// Prevents the use of the copy operator.
  void operator =( const FileModel &copy );

  void findDependencies();

  /// \override
  void fileIncluded( const QString &fileName,
                     bool searchParentDir );

private:
  QString _fullPathName;

  QList<FileDependency> _dependencies;
};



// Inlines methods for FileModel:
// ------------------------------



#endif  // FILEMODEL_H
