// //////////////////////////////////////////////////////////////////////////
// Implementation file FileModelTest.cpp for class FileModelTest
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/18
// //////////////////////////////////////////////////////////////////////////

#include "FileModelTest.h"
#include "FileModel.h"
#include "QtCppUnitTools.h"


namespace CppUnit
{
  struct assertion_traits<FileDependency> : public stringable_traits<FileDependency>
  {
    static bool equal( const FileDependency& x, const FileDependency& y )
    {
      return const_cast<FileDependency &>(x).equalsTo( &const_cast<FileDependency &>(y) );
    }
  };
}



CPPUNIT_TEST_SUITE_REGISTRATION( FileModelTest );


FileModelTest::FileModelTest() : 
    CppUnit::TestCase()
{
}


FileModelTest::~FileModelTest()
{
}


void 
FileModelTest::setUp()
{
  _dir = "../Test/";
}


void 
FileModelTest::tearDown()
{
}


void 
FileModelTest::testGetDependenciesWithEmptyFile()
{
  FileModel file( _dir + "Empty.h" );
  QVector<FileDependency> dependencies = file.dependencies();
  CPPUNIT_ASSERT_EQUAL( 0, int(dependencies.count()) );
}


void 
FileModelTest::testGetDependenciesWithQuotedHeader()
{
  FileModel file( _dir + "QuoteInclude.h" );
  QVector<FileDependency> dependencies = file.dependencies();
  CPPUNIT_ASSERT_EQUAL( 1, int(dependencies.count()) );

  FileDependency dep1( "Header.h", true );
  CPPUNIT_ASSERT_EQUAL( dep1, *dependencies.at(0) );
}


void 
FileModelTest::testGetDependenciesWithAngledHeader()
{
  FileModel file( _dir + "AngleInclude.h" );
  QVector<FileDependency> dependencies = file.dependencies();
  CPPUNIT_ASSERT_EQUAL( 1, int(dependencies.count()) );

  FileDependency dep1( "Header.h", false );
  CPPUNIT_ASSERT_EQUAL( dep1, *dependencies.at(0) );
}


void 
FileModelTest::testGetDependenciesWithMixedHeaders()
{
  FileModel file( _dir + "MixedIncludes.h" );
  QVector<FileDependency> dependencies = file.dependencies();
  CPPUNIT_ASSERT_EQUAL( 2, int(dependencies.count()) );

  FileDependency dep1( "string", false );
  FileDependency dep2( "EmptyHeader.h", true );
  CPPUNIT_ASSERT_EQUAL( dep1, *dependencies.at(0) );
  CPPUNIT_ASSERT_EQUAL( dep2, *dependencies.at(1) );
}
