// //////////////////////////////////////////////////////////////////////////
// Header file ProjectModel.h for class ProjectModel
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////
#ifndef PROJECTMODEL_H
#define PROJECTMODEL_H

#include <qdict.h>
#include <qlist.h>
#include <qstring.h>
class FileDependency;
class FileModel;
class FileModelIterator;
class ResolvedFileModel;


/*! \class ProjectModel
 * \brief This class represents a project and its files.
 */
class ProjectModel
{
public:
  /*! Constructs a ProjectModel object.
   */
  ProjectModel( const QString &projectDirectory );

  /// Destructor.
  virtual ~ProjectModel();

  QString absoluteProjectPath();

  void addFile( const QString &relativeFileName );

  void addProjectRelativeIncludeDirectory( const QString &includeDirectory );

  FileModelIterator files();

  FileModel *fileDependenciesFor( const QString &fullPathName,
                                  bool isBadFileName =false );

  ResolvedFileModel *resolvedDependencyFor( ResolvedFileModel *file,
                                            FileDependency *dependency );

  QString SearchFileInEnvironment( FileDependency *dependency );
  QString SearchFileInParentFileDirectories( 
                                      ResolvedFileModel *file, 
                                      FileDependency *dependency );

private:
  /// Prevents the use of the copy constructor.
  ProjectModel( const ProjectModel &copy );

  /// Prevents the use of the copy operator.
  void operator =( const ProjectModel &copy );

  QString absolutePathFor( const QString &projectRelativeFileName );

private:
  // Absolute project directory
  QString _projectDirectory;

  QList<ResolvedFileModel> *_resolvedFiles;
  QDict<FileModel> *_fileDependencies;
};



// Inlines methods for ProjectModel:
// ---------------------------------



#endif  // PROJECTMODEL_H
