// //////////////////////////////////////////////////////////////////////////
// Header file ProjectModelTest.h for class ProjectModelTest
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////
#ifndef PROJECTMODELTEST_H
#define PROJECTMODELTEST_H

#include <cppunit/extensions/HelperMacros.h>
#include <qstring.h>


/*! \class ProjectModelTest
 * \brief Unit Test for ProjectModel
 */
class ProjectModelTest : public CppUnit::TestCase
{
  CPPUNIT_TEST_SUITE( ProjectModelTest );
  CPPUNIT_TEST( testAbsoluteProjectPath );
  CPPUNIT_TEST( testOneFileAndOneDependency );
  CPPUNIT_TEST( testDirectThreeLevelDependencies );
  CPPUNIT_TEST( testSearchParentDirectory );
  CPPUNIT_TEST( testSearchIncludePathDependencies );
  CPPUNIT_TEST( testSearchParentBeforeIncludePath );
  CPPUNIT_TEST( testSearchParentOnlyIfQuoted );
  CPPUNIT_TEST_SUITE_END();

public:
  /*! Constructs a ProjectModelTest object.
   */
  ProjectModelTest();

  /// Destructor.
  virtual ~ProjectModelTest();

  void setUp();
  void tearDown();

  void testAbsoluteProjectPath();

  void testOneFileAndOneDependency();
  void testDirectThreeLevelDependencies();
  void testSearchParentDirectory();
  void testSearchIncludePathDependencies();
  void testSearchParentBeforeIncludePath();
  void testSearchParentOnlyIfQuoted();

private:
  /// Prevents the use of the copy constructor.
  ProjectModelTest( const ProjectModelTest &copy );

  /// Prevents the use of the copy operator.
  void operator =( const ProjectModelTest &copy );

  QString makePathFor( const QString &projectDirectory,
                       const QString &relativeFileName );

private:
  QString _dir;
};



// Inlines methods for ProjectModelTest:
// -------------------------------------



#endif  // PROJECTMODELTEST_H
