// //////////////////////////////////////////////////////////////////////////
// Implementation file ResolvedFileModel.cpp for class ResolvedFileModel
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////

#include <qstring.h>
#include <stdexcept>
#include "FileModel.h"
#include "FileModelIterator.h"
#include "ProjectModel.h"
#include "ResolvedFileModel.h"


ResolvedFileModel::ResolvedFileModel( ProjectModel *project,
                                      FileModel *file,
                                      ResolvedFileModel *parentFile ) :
    _project( project ),
    _file( file ),
    _dependencyResolved( false ),
    _parentFile( parentFile )
{
}


ResolvedFileModel::~ResolvedFileModel()
{
}


QString 
ResolvedFileModel::directoryPath()
{
  return _file->directoryPath();
}


QString 
ResolvedFileModel::fullPathName()
{
  return _file->fullPathName();
}


FileModelIterator 
ResolvedFileModel::includedFiles()
{
  if ( !_dependencyResolved )
    resolveDependencies();

  return FileModelIterator( 
            QListIterator<ResolvedFileModel>( _includedFiles ) );
}


void 
ResolvedFileModel::resolveDependencies()
{
  QVector<FileDependency> dependencies( _file->dependencies() );
  for ( uint index =0; index < dependencies.count(); ++index )
  {
    ResolvedFileModel *includedFile = 
        _project->resolvedDependencyFor( this, dependencies[index] );
    _includedFiles.append( includedFile );
  }

  _dependencyResolved = true;
}


QString 
ResolvedFileModel::angledPathName()
{
  return "<" + fullPathName() + ">";
}


bool 
ResolvedFileModel::hasParentFile()
{
  return _parentFile != NULL;
}


ResolvedFileModel *
ResolvedFileModel::parentFile()
{
  if ( !hasParentFile() )
    throw std::logic_error( "ResolvedFileModel::parentFile(): no parent file" );
  return _parentFile;
}
