// //////////////////////////////////////////////////////////////////////////
// Header file ResolvedFileModel.h for class ResolvedFileModel
// (c)Copyright 2000, Baptiste Lepilleur.
// Created: 2001/09/23
// //////////////////////////////////////////////////////////////////////////
#ifndef RESOLVEDFILEMODEL_H
#define RESOLVEDFILEMODEL_H

#include <qlist.h>
class FileModel;
class FileModelIterator;
class ProjectModel;
class QString;


/*! \class ResolvedFileModel
 * \brief This class represents a FileModel which is the resolution of a given inclusion.
 */
class ResolvedFileModel
{
public:

  /*! Constructs a ResolvedFileModel object.
   */
  ResolvedFileModel( ProjectModel *project,
                     FileModel *file,
                     ResolvedFileModel *parentFile =NULL );

  /// Destructor.
  virtual ~ResolvedFileModel();

  QString directoryPath();

  QString fullPathName();

  QString angledPathName();

  FileModelIterator includedFiles();

  bool hasParentFile();

  ResolvedFileModel *parentFile();

private:
  /// Prevents the use of the copy constructor.
  ResolvedFileModel( const ResolvedFileModel &copy );

  /// Prevents the use of the copy operator.
  void operator =( const ResolvedFileModel &copy );

  void resolveDependencies();

private:
  FileModel *_file;
  ProjectModel *_project;
  bool _dependencyResolved;
  QList<ResolvedFileModel> _includedFiles;
  ResolvedFileModel *_parentFile;
};



// Inlines methods for ResolvedFileModel:
// --------------------------------------



#endif  // RESOLVEDFILEMODEL_H
